﻿require([
    "dojo/_base/declare",
    'dojo/_base/window',
    'epi-cms/component/MediaViewModel',
    "dojo/_base/array",
    "dojo/_base/declare",
    "dojo/_base/lang",
    "dojo/dom-class",
    "dojo/when",
    "dojo/topic",
    "epi",
    "epi/shell/widget/dialog/Dialog",
    "epi-cms/core/ContentReference",
    "epi-cms/asset/view-model/HierarchicalListViewModel",
    "epi-cms/widget/viewmodel/MultipleFileUploadViewModel",
    "epi-cms/widget/MultipleFileUpload",
    "epi-cms/command/UploadContent",
    "epi-cms/command/EditImage",
    "epi-cms/command/DownloadMedia",
    "epi-cms/asset/command/UploadContentToSelection",
    "epi/i18n!epi/cms/nls/episerver.cms.components.media",
    'dojo/domReady!'
  ], function(declare, win, Media,
    array, declare, lang, domClass, when, topic, epi, Dialog, ContentReference,
    ) {

    var extension = declare(null, {
        currentLang: 'en',
        getLang: function () {
            var lang = navigator.language || navigator.userLanguage;
            if (lang.indexOf('sv') > -1) {
                return 'sv';
            } else if (lang.indexOf('no') > -1) {
                return 'no';
            } else if (lang.indexOf('fi') > -1) {
                return 'fi';
            }
            else {
                return 'en';
            }
        },
        constructor: function () {
            fetch('/api/mediaflow/settings').then((r) => r.json().then((data) => {
                setTimeout(() => {            
                    if(data.enableMediaLibraryUpload){
                        var userProfile = epi.dependency.resolve("epi.shell.Profile");
                        this.username = userProfile.userName;

                        this.currentLang = data.lang ? data.lang : this.getLang();
                        this.lang = data.dictionary[this.currentLang];
                        window.protectedModulesPath = data.protectedPath;
                    
                        this.lookForElement();
                    }
                }, 5000);
            }));  

            // listen for done event mfSelectorDone
            document.addEventListener('mfSelectorDone', (event) => {
                this._clickDone(event.detail);
            });
        },
        addMediaflowButton: function () {
            var dialog = document.querySelector('.dijitDialog');
            if (!dialog) {
                return;
            }
            var insertToElement = dialog.querySelector('.epi-createContentContainer');

            if (insertToElement && insertToElement.innerHTML.indexOf('mediaflow-upload-button-div') == -1) {
                var icon = '<svg width="30" style="fill: #595959;" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><polygon points="0.83 11.42 -0.32 11.43 4.9 3.52 9.38 10.21 8.17 10.19 4.9 5.32 0.83 11.42"/><path d="M13.62,11.64a2.35,2.35,0,0,1-2-1.08l-.26-.38-.83,1.24H9.28l1.49-2.14L9.13,6.81,6.06,11.42H4.84L9.13,5l2.24,3.36L11.66,8a2.34,2.34,0,0,1,2-1,2.37,2.37,0,0,1,0,4.73ZM12,9.27l.49.74a1.37,1.37,0,1,0,0-1.5Z"/></svg>';
                var div = document.createElement('div');
                div.classList.add('mediaflow-upload-button-div');
                div.innerHTML = '<button style="width: 90%;padding: 3px;margin: 2px auto;" class="mediaflow-upload-button dijitButtonNode epi-button--full-width">'+icon+' '+this.lang.addFromMediaflow+'</button>';

                dialog.querySelector('.epi-createContentContainer .dijitButton').after(div);
                this.registerMediaflowButton();
            }
        },
        registerMediaflowButton: function () {
            var mfButton = document.querySelectorAll('.mediaflow-upload-button');
            mfButton.forEach((elem) => {
                elem.addEventListener('click', (e) => {
                    var mediaFolderSelected = document.querySelector('.dijitDialog .dijitTreeRowSelected');
                    var folderId = 0;
                    
                    // parse folder id from title
                    if (mediaFolderSelected) {
                        var title = mediaFolderSelected.title;
                        var titleParts = title.split(' ');
        
                        folderId = titleParts.find((part) => {
                            return !isNaN(part);
                        });
                    }

                    this._showChildDialog(true, folderId);
                });
            });
        },
        _showChildDialog: function (mediaflowButton = false, folderId = 0) {
            var w, h, dialogurl, mediaID, autoPlay, startAt, embedType, selectedID, selectedFolder;
            if (window.innerHeight) {
                w = window.innerWidth;
                h = window.innerHeight;
            } else {
                h = document.compatMode !== 'BackCompat' ? document.documentElement.clientHeight : document.body.clientHeight;
                w = document.compatMode !== 'BackCompat' ? document.documentElement.clientWidth : document.body.clientWidth;
            }
    
            selectedID = '0';
            if (this.value && this.value.selectedID > 0)
                selectedID = this.value.selectedID;
            selectedFolder = '0';
            if (this.value && this.value.selectedFolder > 0)
                selectedFolder = this.value.selectedFolder;
    
            dialogurl = window.protectedModulesPath + 'Mediaflow.Optimizely/Scripts/mfSelector/dialog.html?id=' + this.id + '&mid=' + mediaID + '&ap=' + autoPlay + '&sa=' + startAt + '&et=' + embedType + '&si=' + selectedID + '&sf=' + selectedFolder + '&username=' + this.username + '&lang=' + this.currentLang+'&mediaflowButton='+mediaflowButton+'&folderId='+folderId;
            
            if(mediaflowButton){
                dialogurl += '&type=image';
            }
            
            this._dialog = dijit.Dialog(
                {
                    title: this.lang.addFromMediaflow,
                    content: '<iframe width="1200px" height="' + (h - 200) + '" frameborder="0" style="width:90vw; background-color:#000;" src="' + dialogurl + '"></iframe>'
                });
            this.isShowingChildDialog = true;
            this._dialog.containerNode.style.padding = '0';
            this._dialog.domNode.style.zIndex = '9999';
            this._dialog.show();
            this._dialog.domNode.style.zIndex = '9999';
        },
        _clickDone: function (o) {
            var context = epi.dependency.resolve("epi.shell.ContextService").currentContext;
            var pageId = context.id.split('_')[0];
            var folderId = o.folderId;
    
            if (o.basetype == 'image') {
                fetch('/api/mediaflow/upload?imageUrl=' + o.url + '&fileName=' + o.filename + '&fileId=' + o.id + '&pageId=' + pageId+'&folderId='+o.folderId).then((r) => r.json().then((data) => {
                    var v = {
                        width: o.width,
                        height: o.height,
                        fileId: data.fileId,
                        fileUrl: data.fileUrl,
                        altText: o.altText,
                        embedCode: '',
                        autoPlay: null,
                        mediaId: null,
                        startAt: 0,
                        embedType: null,
                        type: o.basetype,
                        selectedId: o.id,
                        selectedFolder: o.selectedFolder
                    };

                    this._dialog.hide();
    
                    if(folderId){
                        // try to reload the image dialog
                        window.epi.shell.messaging.publish('/epi/cms/upload');
                    }
                }));
            }
        },
        lookForElement: function () {
            var observer = new MutationObserver((mutations) => {
                mutations.forEach((mutation) => {
                    var nodes = Array.from(mutation.addedNodes);
                    for (var node of nodes) {
                        if (node && node.classList && node.classList.contains('dijitDialog')) {
                            this.addMediaflowButton();
                        }
                    };
                });
            });

            observer.observe(document.documentElement, { childList: true, subtree: true });
        }
      });

    extension();
});
