﻿define(
	[
		"epi-cms/widget/_HasChildDialogMixin",
		"dojo/_base/declare",
		"dijit/_Widget",
		"dijit/_TemplatedMixin",
		"dojo/html",

		"epi/_Module",
		"epi/dependency",
		"epi/routes",
		"epi/shell/_ContextMixin",
	],
	function (
		_HasChildDialogMixin,
		declare,
		_Widget,
		_TemplatedMixin,
		html,

		//CMS
		_Module,
		dependency,
		routes,
		_ContextMixin,
	) {
		return declare([_Widget, _TemplatedMixin, _HasChildDialogMixin, _ContextMixin],
			{
				templateString: '<div class="dijitInline sleek"><div class="epi-content-selector-plugnplay-actionsContainer" style="cursor:pointer;" data-dojo-attach-point="bbild"></div><div style=\"cursor:pointer; color: #bb1515;\" data-dojo-attach-point=\"bortbild\"></div></div>',
			
				constructor: async function () {
					var result = await fetch('/api/mediaflow/settings');
					var data = await result.json();
					window.protectedModulesPath = data.protectedPath;
					this.currentLang = data.lang ? data.lang : this.getLang();
					this.lang = data.dictionary[this.currentLang];
					
					// when loaded set value again to update the view
					this._setValueAttr(this.value);
				},
				getLang: function () {
					var lang = navigator.language || navigator.userLanguage;

					if (lang.indexOf('sv') > -1) {
						return 'sv';
					} else if (lang.indexOf('no') > -1) {
						return 'no';
					} else if (lang.indexOf('fi') > -1) {
						return 'fi';
					}
					else {
						return 'en';
					}
				},
				_setValueAttr: function (value) {

					if (value) {
						this._set('value', value);
					}

					if (value && value.type == 'video') {
						html.set(this.bbild, '<img src="https://m.mediaflow.com/poster/' + value.mediaId + '?w=192&h=108" style="max-width: 300px;" />');
						html.set(this.bortbild, this.lang.removeMedia);
					} else if (value && value.type == 'image') {
						html.set(this.bbild, '<img src="' + value.fileUrl + '" style="max-width: 300px;" />');
						html.set(this.bortbild, this.lang.removeMedia);
					} else {
						html.set(this.bbild, `<span class="dijit dijitReset dijitInline dijitButton dijitButtonFocused dijitFocused"><span class="dijitReset dijitInline dijitButtonNode"><span class="dijitReset dijitStretch dijitButtonContents"><span class="dijitReset dijitInline dijitButtonText">${this.lang.clickHere}</span></span></span></span>`);
						html.set(this.bortbild, '');
					}
				},

				postCreate: function () {
					var userProfile = dependency.resolve("epi.shell.Profile");
					this.username = userProfile.userName;

					// summary : Connects keyboard events of the email textbox to update the value of the editor.
					// tags    : protected
					this.connect(this.bbild, 'onclick', this._onClicka);
					this.connect(this.bortbild, 'onclick', this._bortclick);
				},

				_onClicka: function (event) {
					if (this.readOnly) {
						alert(this.lang.noPermissionToEdit);
						return;
					}
					this._showChildDialog();
				},
				_bortclick: function (event) {
					if (this.readOnly) {
						alert(this.lang.noPermissionToRemove);
						return;
					}

					var v = { width: 0, height: 0, autoPlay: false, mediaID: '', embedCode: '', startAt: 0, embedType: '' };
					this._set('value', v);
					this.onChange(v);
					html.set(this.bbild, `<span class="dijit dijitReset dijitInline dijitButton dijitButtonFocused dijitFocused"><span class="dijitReset dijitInline dijitButtonNode"><span class="dijitReset dijitStretch dijitButtonContents"><span class="dijitReset dijitInline dijitButtonText">${this.lang.clickHere}</span></span></span></span>`);
					html.set(this.bortbild, '');
				},
				_clickDone: function (o) {
					var context = this.getCurrentContext();
					var pageId = context.id.split('_')[0];

					if (o.basetype == 'image') {
						fetch('/api/mediaflow/upload?imageUrl=' + o.url + '&fileName=' + o.filename + '&fileId=' + o.id + '&pageId=' + pageId).then((r) => r.json().then((data) => {
							var v = {
								width: o.width,
								height: o.height,
								fileId: data.fileId,
								fileUrl: data.fileUrl,
								altText: o.altText,
								photographer: o.photographer,
								embedCode: '',
								autoPlay: null,
								mediaId: null,
								startAt: 0,
								embedType: null,
								type: o.basetype,
								selectedId: o.id,
								selectedFolder: o.selectedFolder
							};
							this._set('value', v);

							this.onChange(v);
							html.set(this.bbild, '<img src="' + data.fileUrl + '" title="' + this.lang.clickHere + '" style="max-width: 300px;" />');
							html.set(this.bortbild, this.lang.removeMedia);
							this._dialog.hide();
						}));
					} else if (o.basetype == 'video') {
						if (!o.mediaId) {
							alert('Ett fel inträffade när videon skulle sparas (mediaId == null)!');
							this._dialog.hide();
							return;
						}

						fetch('/api/mediaflow/report?fileId=' + o.id + '&pageId=' + pageId).then((data) => { });

						var v = { fileId: null, fileUrl: '', altText: o.altText ?? '', photographer: o.photographer ?? '', type: o.basetype, embedCode: o.embedCode, autoPlay: o.autoPlay, mediaId: o.mediaId, startAt: o.startTime, embedType: o.embedMethod, selectedId: o.id, selectedFolder: o.selectedFolder };
						this._set('value', v);
						this.onChange(v);
						html.set(this.bbild, '<img src="https://m.mediaflow.com/poster/' + v.mediaId + '?w=192&h=108" title="' + this.lang.clickHere + '" />');
						html.set(this.bortbild, this.lang.removeMedia);
						this._dialog.hide();
					}
				},
				_showChildDialog: function () {
					var w, h, dialogurl, mediaID, autoPlay, startAt, embedType, selectedID, selectedFolder;
					if (window.innerHeight) {
						w = window.innerWidth;
						h = window.innerHeight;
					} else {
						h = document.compatMode !== 'BackCompat' ? document.documentElement.clientHeight : document.body.clientHeight;
						w = document.compatMode !== 'BackCompat' ? document.documentElement.clientWidth : document.body.clientWidth;
					}
					mediaID = '';
					if (this.value && this.value.mediaID)
						mediaID = this.value.mediaID;
					autoPlay = '0';
					if (this.value && this.value.autoPlay === true)
						autoPlay = '1';
					startAt = '0';
					if (this.value && this.value.startAt > 0)
						startAt = this.value.startAt;
					embedType = '0';
					if (this.value && this.value.embedType == 'iframe')
						embedType = '1';
					selectedID = '0';
					if (this.value && this.value.selectedID > 0)
						selectedID = this.value.selectedID;
					selectedFolder = '0';
					if (this.value && this.value.selectedFolder > 0)
						selectedFolder = this.value.selectedFolder;

					dialogurl = window.protectedModulesPath + 'Mediaflow.Optimizely/Scripts/mfSelector/dialog.html?id=' + this.id + '&mid=' + mediaID + '&ap=' + autoPlay + '&sa=' + startAt + '&et=' + embedType + '&si=' + selectedID + '&sf=' + selectedFolder + '&username=' + this.username + '&lang=' + this.currentLang;
	
					this._dialog = dijit.Dialog(
						{
							title: this.lang.addFromMediaflow,
							content: '<iframe width="1200px" height="' + (h - 200) + '" frameborder="0" style="width:90vw; background-color:#000;" src="' + dialogurl + '"></iframe>'
						});
					this.connect(this._dialog, 'onHide', this._onHide);
					this.isShowingChildDialog = true;
					this._dialog.show();
				},

				_onHide: function () {
					this.isShowingChildDialog = false;
				}
			})
	}
);